/****************************************************************************
** Meta object code from reading C++ file 'calprintdefaultplugins.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../calendarsupport-26.07.90/src/printing/calprintdefaultplugins.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calprintdefaultplugins.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSupport::CalPrintIncidenceConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSupport::CalPrintIncidenceConfig"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalPrintIncidenceConfig, qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarSupport::CalPrintIncidenceConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>.metaTypes,
    nullptr
} };

void CalendarSupport::CalPrintIncidenceConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalPrintIncidenceConfig *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarSupport::CalPrintIncidenceConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarSupport::CalPrintIncidenceConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport23CalPrintIncidenceConfigE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CalPrintIncidenceConfig_Base"))
        return static_cast< Ui::CalPrintIncidenceConfig_Base*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarSupport::CalPrintIncidenceConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSupport::CalPrintDayConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSupport::CalPrintDayConfig"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalPrintDayConfig, qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarSupport::CalPrintDayConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>.metaTypes,
    nullptr
} };

void CalendarSupport::CalPrintDayConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalPrintDayConfig *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarSupport::CalPrintDayConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarSupport::CalPrintDayConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport17CalPrintDayConfigE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CalPrintDayConfig_Base"))
        return static_cast< Ui::CalPrintDayConfig_Base*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarSupport::CalPrintDayConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSupport::CalPrintWeekConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSupport::CalPrintWeekConfig"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalPrintWeekConfig, qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarSupport::CalPrintWeekConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>.metaTypes,
    nullptr
} };

void CalendarSupport::CalPrintWeekConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalPrintWeekConfig *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarSupport::CalPrintWeekConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarSupport::CalPrintWeekConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintWeekConfigE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CalPrintWeekConfig_Base"))
        return static_cast< Ui::CalPrintWeekConfig_Base*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarSupport::CalPrintWeekConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSupport::CalPrintMonthConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSupport::CalPrintMonthConfig"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalPrintMonthConfig, qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarSupport::CalPrintMonthConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>.metaTypes,
    nullptr
} };

void CalendarSupport::CalPrintMonthConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalPrintMonthConfig *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarSupport::CalPrintMonthConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarSupport::CalPrintMonthConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport19CalPrintMonthConfigE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CalPrintMonthConfig_Base"))
        return static_cast< Ui::CalPrintMonthConfig_Base*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarSupport::CalPrintMonthConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSupport::CalPrintTodoConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSupport::CalPrintTodoConfig"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalPrintTodoConfig, qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarSupport::CalPrintTodoConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>.metaTypes,
    nullptr
} };

void CalendarSupport::CalPrintTodoConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalPrintTodoConfig *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarSupport::CalPrintTodoConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarSupport::CalPrintTodoConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalendarSupport18CalPrintTodoConfigE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CalPrintTodoConfig_Base"))
        return static_cast< Ui::CalPrintTodoConfig_Base*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarSupport::CalPrintTodoConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
